import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_user_agent/flutter_user_agent.dart';
import 'package:share_apps/widgets/widgets_importer.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'invitaion_complete_screen.dart';

class InviteEmail extends StatefulWidget {
  String url, first_loaded_url;
  bool isProgressShow = true, isFirst = true;

  InviteEmail(this.url);

  @override
  _InviteEmailState createState() => _InviteEmailState();
}

class _InviteEmailState extends State<InviteEmail> {
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();
  String _userAgent = '<unknown>', _webUserAgent = '<unknown>';

  @override
  void initState() {
    super.initState();
    initUserAgentState();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        color: Colors.white,
        home: Scaffold(
          appBar: AppBar(
            title: const Text('Invite by Email'),
            // This drop down menu demonstrates that Flutter widgets can be shown over the web view.
            actions: <Widget>[
              IconButton(
                icon: const Icon(Icons.done),
                onPressed: () {
                  Route route =
                  MaterialPageRoute(builder: (context) => InvitationComplete());
                  Navigator.pushReplacement(context, route);
                },
              ),
            ],
          ),
          body: Builder(builder: (BuildContext context) {
            return Stack(
              children: <Widget>[
                WebView(
                  userAgent: _userAgent,
                  initialUrl: widget.url,
                  javascriptMode: JavascriptMode.unrestricted,
                  onWebViewCreated: (WebViewController webViewController) {
                    _controller.complete(webViewController);
                  },
                  javascriptChannels: <JavascriptChannel>[
                    _toasterJavascriptChannel(context),
                  ].toSet(),
                  navigationDelegate: (NavigationRequest request) {
                    return NavigationDecision.navigate;
                  },
                  onPageStarted: (String url) {
                    setState(() {
                      widget.isProgressShow = true;
                    });
                  },
                  onPageFinished: (String url) {
                    setState(() {
                      widget.isProgressShow = false;
                    });
                  },
                  gestureNavigationEnabled: true,
                ),
                Visibility(visible: widget.isProgressShow, child: addProgress())
              ],
            );
          }),
        ),
      ),
    );
  }

  JavascriptChannel _toasterJavascriptChannel(BuildContext context) {
    return JavascriptChannel(
        name: 'Toaster',
        onMessageReceived: (JavascriptMessage message) {
          Scaffold.of(context).showSnackBar(
            SnackBar(content: Text(message.message)),
          );
        });
  }

  Future<void> initUserAgentState() async {
    String userAgent, webViewUserAgent;
    try {
      userAgent = await FlutterUserAgent.getPropertyAsync('userAgent');
      await FlutterUserAgent.init();
      webViewUserAgent = FlutterUserAgent.webViewUserAgent;
      print('''
--- applicationVersion => ${FlutterUserAgent.getProperty('applicationVersion')}
--- systemName         => ${FlutterUserAgent.getProperty('systemName')}
--- userAgent          => $userAgent
--- webViewUserAgent   => $webViewUserAgent
--- packageUserAgent   => ${FlutterUserAgent.getProperty('packageUserAgent')}
      ''');
    } on PlatformException {
      userAgent = webViewUserAgent = '<error>';
    }
    if (!mounted) return;
    setState(() {
      _userAgent = userAgent;
      _webUserAgent = webViewUserAgent;
    });
  }
}

enum MenuOptions {
  showUserAgent,
  listCookies,
  clearCookies,
  addToCache,
  listCache,
  clearCache,
  navigationDelegate,
}
