import 'dart:convert';
import 'dart:io';

import 'package:device_id/device_id.dart';
import 'package:flutter/material.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/app_registration_screen.dart';
import 'package:share_apps/screens/country_language_selection_form.dart';
import 'package:share_apps/screens/invitation_form.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../utils/common_utils.dart';
import '../utils/list_utils.dart';
import '../utils/string_utils.dart';

class ShareApps {
  static init({String secreteKey, String appId, String email}) {
    StringUtils.APP_ID = appId;
    StringUtils.APP_SECRET = secreteKey;
    StringUtils.APP_EMAIL = email;
  }

  static sendInvitation({BuildContext context}) async {
    if (StringUtils.APP_ID.isEmpty ||
        StringUtils.APP_SECRET.isEmpty ||
        StringUtils.APP_EMAIL.isEmpty) {
      CommonUtils.showToast(
          "Please initialize app with appId, secreteKey and your registered email",
          Colors.black);
      return;
    }
    final prefs = await SharedPreferences.getInstance();
    if (prefs.getString(StringUtils.USER_DATA) == null) {
      Navigator.push(
          context,
          MaterialPageRoute(
              builder: (context) =>
                  InvitationForm(new UserBean('', '', '', '', '', '', ''))));
    } else {
      Map jsons = json.decode(prefs.getString(StringUtils.USER_DATA));
      UserBean bean = UserBean(
          jsons['first_name'],
          jsons['last_name'],
          jsons['email'],
          jsons['phone'],
          jsons['country_id'],
          jsons['language'],
          jsons['deviceId']);
      showDialog<void>(
        context: context,
        barrierDismissible: false, // user must tap button!
        builder: (BuildContext context) {
          return AlertDialog(
            title: Text('Are you continue with saved data or Edit?'),
            actions: <Widget>[
              FlatButton(
                child: Text('Edit'),
                onPressed: () {
                  Navigator.of(context).pop();
                  Navigator.pushReplacement(
                      context,
                      MaterialPageRoute(
                          builder: (context) => InvitationForm(bean)));
                },
              ),
              FlatButton(
                child: Text('Continue'),
                onPressed: () async {
                  Navigator.of(context).pop();
                  try {
                    final result = await InternetAddress.lookup('google.com');
                    if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
                      Route route = MaterialPageRoute(
                          builder: (context) => AppRegistrationScreen(bean));
                      Navigator.push(context, route);
                    }
                  } on SocketException catch (_) {
                    CommonUtils.showToast(
                        StringUtils.CHECK_NETWORK, Colors.red);
                  }
                  //openNextScreen(context, bean);
                },
              ),
            ],
          );
        },
      );
    }
  }

  static sendInvitationInBackground(
      {BuildContext context,
      String firstName,
      String lastName,
      String email,
      String number,
      String countryName,
      String language}) async {
    if (StringUtils.APP_ID.isEmpty ||
        StringUtils.APP_SECRET.isEmpty ||
        StringUtils.APP_EMAIL.isEmpty) {
      CommonUtils.showToast(
          "Please initialize app with appId, secreteKey and your registered email address",
          Colors.black);
      return;
    }
    if (firstName.length <= 0) {
      CommonUtils.showToast(StringUtils.ERROR_FIRST_NAME, Colors.red);
    } else if (lastName.length <= 0) {
      CommonUtils.showToast(StringUtils.ERROR_LAST_NAME, Colors.red);
    } else if (email.length <= 0) {
      CommonUtils.showToast(StringUtils.ERROR_EMAIL, Colors.red);
    } else if (!CommonUtils.validateEmail(email)) {
      CommonUtils.showToast(StringUtils.ERROR_VALID_EMAIL, Colors.red);
    } else if (number.length < 5) {
      CommonUtils.showToast(StringUtils.ERROR_NUMBER, Colors.red);
    }
    /* else if (countryName == ListUtil.country_list[0]) {
      CommonUtils.showToast(countryName, Colors.red);
    } else if (!ListUtil.country_list.contains(countryName)) {
      CommonUtils.showToast(StringUtils.ERROR_COUNTRY, Colors.red);
    } else if (language == ListUtil.language_list[0]) {
      CommonUtils.showToast(language, Colors.red);
    } else if (!ListUtil.language_list.contains(language)) {
      CommonUtils.showToast(StringUtils.ERROR_LANGUAGE, Colors.red);
    } */
    else {
      UserBean bean = new UserBean(
          firstName,
          lastName,
          email,
          number,
          (ListUtil.country_list.indexOf(countryName).toString()),
          language,
          await DeviceId.getID);
      final prefs = await SharedPreferences.getInstance();
      prefs.setString(StringUtils.USER_DATA, jsonEncode(bean.toJson()));
      try {
        final result = await InternetAddress.lookup('google.com');
        if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
          Route route = MaterialPageRoute(
              builder: (context) => CountryLangaugeSelectionForm(bean));
          Navigator.push(context, route);
        }
      } on SocketException catch (_) {
        CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
      }
    }
  }
}
